@@ -80,6 +80,15 @@ class DelegateSafe(ApeSafe):
         super().post_transaction(safe_tx)
 
         if self.is_ci and self.is_send:
+            if "{1}" in self.frontend_url:
+                formatted_frontend_url = self.frontend_url.format(self.address, safe_tx.safe_tx_hash)
+            else:
+                formatted_frontend_url = self.frontend_url.format(self.address)
+
+            with open(os.getenv('GITHUB_ENV'), 'a') as f:
+                f.write("SAFE_LINK={0}\n".format(formatted_frontend_url))
+            with open(os.path.join(home_directory, "safe.txt"), "w") as f:
+                f.write(str(formatted_frontend_url))
             with open(os.getenv('GITHUB_ENV'), 'a') as f:
                 f.write("NONCE={0}\n".format(str(safe_tx.safe_nonce)))
             with open(os.path.join(home_directory, "nonce.txt"), "w") as f:
@@ -131,12 +140,6 @@ class DelegateSafe(ApeSafe):
         if not self.is_ci:
             return super().get_signer(signer)
 
-        with open(os.getenv('GITHUB_ENV'), 'a') as f:
-            f.write("SAFE_LINK={0}\n".format(str(self.frontend_url.format(self.address))))
-        
-        with open(os.path.join(home_directory, "safe.txt"), "w") as f:
-            f.write(str(self.frontend_url.format(self.address)))
-
         if self.is_send:
             key = os.environ.get("PRIVATE_KEY")
             assert (
@@ -155,20 +158,11 @@ class DelegateSafe(ApeSafe):
         if not self.is_ci:
             return super().sign_transaction(safe_tx, signer)
 
-        if "{1}" in self.frontend_url:
-            formatted_frontend_url = self.frontend_url.format(self.address, safe_tx)
-        else:
-            formatted_frontend_url = self.frontend_url.format(self.address)
-
-        with open(os.getenv('GITHUB_ENV'), 'a') as f:
-            f.write("SAFE_LINK={0}\n".format(formatted_frontend_url))
-        
-        with open(os.path.join(home_directory, "safe.txt"), "w") as f:
-            f.write(str(formatted_frontend_url))
-
         if not self.is_send:
             print("CI dry-run enabled, set send to true to run to completion")
             exit(0)
+        
+        return super().sign_transaction(safe_tx, signer)
 
 with open(os.path.join(home_directory, "alive.signal"), "w") as f:
     f.write("I am alive")
