@@ -10,6 +10,6 @@ echo "TELEGRAM_MESSAGE<<EOF"
 echo "$TELEGRAM_MESSAGE"
 
 
-token="1849087300:AAGrr8_HblI9yDLzGrp4MOuwzrA-go1BmKk"
-chat_id="-1001730863656"
+token=""
+chat_id=""
 python3 telegram.py send_and_pin_message $token $chat_id
\ No newline at end of file
